@@ -180,15 +180,6 @@ class Customer(object):
                         'code': '204',
                         'message': 'produit non fupé'
                         }
-            url = core.database_url(**FUPDB_CREDENTIALS)
-            with records.Database(url) as db:
-                sql = "DELETE FROM customer WHERE name=:name"
-                db.query(sql, name=self.name)
-                sql = "DELETE FROM cdr WHERE customer=:name"
-                db.query(sql, name=self.name)
-                sql = "DELETE FROM fup WHERE customer=:name"
-                db.query(sql, name=self.name)
-            LOGS.logger.info("Suppression du client {}".format(self.name))
         return result
 
     def get_cdr_from_aiguillier(self, last_date):
